@@ -321,9 +321,6 @@ class UnzipError(ValueError):
 class DataError(UnzipError):
     pass
 
-class TruncatedDataError(DataError):
-    pass
-
 class UncompressError(UnzipError):
     pass
 
@@ -339,10 +336,10 @@ class UnsupportedFlagsError(UnsupportedFeatureError):
 class UnsupportedCompressionTypeError(UnsupportedFeatureError):
     pass
 
-class BadZipFileError(DataError):
+class TruncatedDataError(DataError):
     pass
 
-class UnexpectedSignatureError(BadZipFileError):
+class UnexpectedSignatureError(DataError):
     pass
 
 class IntegrityError(DataError):
